@@ -458,6 +458,7 @@ var NAVTREE =
     [ "Doxygen's Internals", "arch.html", null ],
     [ "Changelog", "changelog.html", [
       [ "1.13 Series", "changelog.html#log_1_13", [
+        [ "Release 1.13.1", "changelog.html#log_1_13_1", null ],
         [ "Release 1.13.0", "changelog.html#log_1_13_0", null ]
       ] ],
       [ "1.12 Series", "changelog.html#log_1_12", [
@@ -521,7 +522,7 @@ var NAVTREE =
 var NAVTREEINDEX =
 [
 "additional.html",
-"commands.html#cmdsee"
+"commands.html#cmdsection"
 ];
 
 var SYNCONMSG = 'click to disable panel synchronization';
